#!/bin/sh

if [ -e /etc/zfs/zpool.cache ]; then
    /usr/sbin/zpool import -N -a -c /etc/zfs/zpool.cache || exit 0
else
    /usr/sbin/zpool import -N -a -o cachefile=none || exit 0
fi

/usr/sbin/zfs mount -a -l || exit 0
/usr/sbin/zfs share -a || :
